@@ -9,7 +9,9 @@
 
 TEST (2, sf, 301.0)
 TEST (4, sf, 302.0)
+TEST (8, sf, 303.0)
 TEST (16, sf, 304.0)
 TEST (2, df, 402.0)
+TEST (4, df, 402.0)
 
 #endif
